@@ -126,6 +126,7 @@ class Instance(
         "enable_kibana_public": "enableKibanaPublic",
         "enable_public": "enablePublic",
         "instance_charge_type": "instanceChargeType",
+        "kibana_node": "kibanaNode",
         "kibana_whitelist": "kibanaWhitelist",
         "master_node": "masterNode",
         "period": "period",
@@ -135,6 +136,7 @@ class Instance(
         "tags": "tags",
         "yml_config": "ymlConfig",
         "zone_count": "zoneCount",
+        "zone_id": "zoneId",
     },
 )
 class InstanceProps:
@@ -150,6 +152,7 @@ class InstanceProps:
         enable_kibana_public: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
         enable_public: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
         instance_charge_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        kibana_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.KibanaNodeProperty"]] = None,
         kibana_whitelist: typing.Optional[typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable]] = None,
         master_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.MasterNodeProperty"]] = None,
         period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
@@ -159,6 +162,7 @@ class InstanceProps:
         tags: typing.Optional[typing.Sequence["RosInstance.TagsProperty"]] = None,
         yml_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.YMLConfigProperty"]] = None,
         zone_count: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+        zone_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::ElasticSearch::Instance``.
 
@@ -171,6 +175,7 @@ class InstanceProps:
         :param enable_kibana_public: Property enableKibanaPublic: Enables or disables Internet access to Kibana.
         :param enable_public: Property enablePublic: Whether enable public access. If properties is true, will allocate public address.Default: false.
         :param instance_charge_type: Property instanceChargeType: Valid values are PrePaid, PostPaid, Default to PostPaid.
+        :param kibana_node: Property kibanaNode: The dedicated kibana node setting.
         :param kibana_whitelist: Property kibanaWhitelist: Set the Kibana's IP whitelist in internet network.
         :param master_node: Property masterNode: The dedicated master node setting. If specified, dedicated master node will be created.
         :param period: Property period: The duration that you will buy Elasticsearch instance (in month). It is valid when instance_charge_type is PrePaid. Valid values: [1~9], 12, 24, 36. Default to 1.
@@ -180,6 +185,7 @@ class InstanceProps:
         :param tags: Property tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
         :param yml_config: Property ymlConfig: In the YML Configuration section of the Cluster Configuration page of your Alibaba Cloud Elasticsearch cluster, you can enable the Auto Indexing, Audit Log Indexing, or Watcher feature.
         :param zone_count: Property zoneCount: undefined.
+        :param zone_id: Property zoneId: The zone id of elasticsearch.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "data_node": data_node,
@@ -197,6 +203,8 @@ class InstanceProps:
             self._values["enable_public"] = enable_public
         if instance_charge_type is not None:
             self._values["instance_charge_type"] = instance_charge_type
+        if kibana_node is not None:
+            self._values["kibana_node"] = kibana_node
         if kibana_whitelist is not None:
             self._values["kibana_whitelist"] = kibana_whitelist
         if master_node is not None:
@@ -215,6 +223,8 @@ class InstanceProps:
             self._values["yml_config"] = yml_config
         if zone_count is not None:
             self._values["zone_count"] = zone_count
+        if zone_id is not None:
+            self._values["zone_id"] = zone_id
 
     @builtins.property
     def data_node(
@@ -298,6 +308,14 @@ class InstanceProps:
         result = self._values.get("instance_charge_type")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def kibana_node(
+        self,
+    ) -> typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.KibanaNodeProperty"]]:
+        '''Property kibanaNode: The dedicated kibana node setting.'''
+        result = self._values.get("kibana_node")
+        return typing.cast(typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.KibanaNodeProperty"]], result)
+
     @builtins.property
     def kibana_whitelist(
         self,
@@ -380,6 +398,14 @@ class InstanceProps:
         result = self._values.get("zone_count")
         return typing.cast(typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def zone_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property zoneId: The zone id of elasticsearch.'''
+        result = self._values.get("zone_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -673,6 +699,23 @@ class RosInstance(
     ) -> None:
         jsii.set(self, "instanceChargeType", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="kibanaNode")
+    def kibana_node(
+        self,
+    ) -> typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.KibanaNodeProperty"]]:
+        '''
+        :Property: kibanaNode: The dedicated kibana node setting.
+        '''
+        return typing.cast(typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.KibanaNodeProperty"]], jsii.get(self, "kibanaNode"))
+
+    @kibana_node.setter
+    def kibana_node(
+        self,
+        value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosInstance.KibanaNodeProperty"]],
+    ) -> None:
+        jsii.set(self, "kibanaNode", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kibanaWhitelist")
     def kibana_whitelist(
@@ -828,6 +871,23 @@ class RosInstance(
     ) -> None:
         jsii.set(self, "zoneCount", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="zoneId")
+    def zone_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: zoneId: The zone id of elasticsearch.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "zoneId"))
+
+    @zone_id.setter
+    def zone_id(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "zoneId", value)
+
     @jsii.data_type(
         jsii_type="@alicloud/ros-cdk-elasticsearch.RosInstance.DataNodeProperty",
         jsii_struct_bases=[],
@@ -944,6 +1004,44 @@ class RosInstance(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="@alicloud/ros-cdk-elasticsearch.RosInstance.KibanaNodeProperty",
+        jsii_struct_bases=[],
+        name_mapping={"spec": "spec"},
+    )
+    class KibanaNodeProperty:
+        def __init__(
+            self,
+            *,
+            spec: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        ) -> None:
+            '''
+            :param spec: 
+            '''
+            self._values: typing.Dict[str, typing.Any] = {
+                "spec": spec,
+            }
+
+        @builtins.property
+        def spec(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+            '''
+            :Property: spec: The dedicated kibana node spec.
+            '''
+            result = self._values.get("spec")
+            assert result is not None, "Required property 'spec' is missing"
+            return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "KibanaNodeProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="@alicloud/ros-cdk-elasticsearch.RosInstance.MasterNodeProperty",
         jsii_struct_bases=[],
@@ -1222,6 +1320,7 @@ class RosInstance(
         "enable_kibana_public": "enableKibanaPublic",
         "enable_public": "enablePublic",
         "instance_charge_type": "instanceChargeType",
+        "kibana_node": "kibanaNode",
         "kibana_whitelist": "kibanaWhitelist",
         "master_node": "masterNode",
         "period": "period",
@@ -1231,6 +1330,7 @@ class RosInstance(
         "tags": "tags",
         "yml_config": "ymlConfig",
         "zone_count": "zoneCount",
+        "zone_id": "zoneId",
     },
 )
 class RosInstanceProps:
@@ -1246,6 +1346,7 @@ class RosInstanceProps:
         enable_kibana_public: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
         enable_public: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
         instance_charge_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        kibana_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.KibanaNodeProperty]] = None,
         kibana_whitelist: typing.Optional[typing.Union[typing.Sequence[typing.Any], ros_cdk_core.IResolvable]] = None,
         master_node: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.MasterNodeProperty]] = None,
         period: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
@@ -1255,6 +1356,7 @@ class RosInstanceProps:
         tags: typing.Optional[typing.Sequence[RosInstance.TagsProperty]] = None,
         yml_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.YMLConfigProperty]] = None,
         zone_count: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+        zone_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::ElasticSearch::Instance``.
 
@@ -1267,6 +1369,7 @@ class RosInstanceProps:
         :param enable_kibana_public: 
         :param enable_public: 
         :param instance_charge_type: 
+        :param kibana_node: 
         :param kibana_whitelist: 
         :param master_node: 
         :param period: 
@@ -1276,6 +1379,7 @@ class RosInstanceProps:
         :param tags: 
         :param yml_config: 
         :param zone_count: 
+        :param zone_id: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "data_node": data_node,
@@ -1293,6 +1397,8 @@ class RosInstanceProps:
             self._values["enable_public"] = enable_public
         if instance_charge_type is not None:
             self._values["instance_charge_type"] = instance_charge_type
+        if kibana_node is not None:
+            self._values["kibana_node"] = kibana_node
         if kibana_whitelist is not None:
             self._values["kibana_whitelist"] = kibana_whitelist
         if master_node is not None:
@@ -1311,6 +1417,8 @@ class RosInstanceProps:
             self._values["yml_config"] = yml_config
         if zone_count is not None:
             self._values["zone_count"] = zone_count
+        if zone_id is not None:
+            self._values["zone_id"] = zone_id
 
     @builtins.property
     def data_node(
@@ -1401,6 +1509,16 @@ class RosInstanceProps:
         result = self._values.get("instance_charge_type")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def kibana_node(
+        self,
+    ) -> typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.KibanaNodeProperty]]:
+        '''
+        :Property: kibanaNode: The dedicated kibana node setting.
+        '''
+        result = self._values.get("kibana_node")
+        return typing.cast(typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosInstance.KibanaNodeProperty]], result)
+
     @builtins.property
     def kibana_whitelist(
         self,
@@ -1493,6 +1611,16 @@ class RosInstanceProps:
         result = self._values.get("zone_count")
         return typing.cast(typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def zone_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: zoneId: The zone id of elasticsearch.
+        '''
+        result = self._values.get("zone_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
